@@ -8,9 +8,7 @@ use in_memory::InMemoryBackend;
 use pixi_build_types::{
     BackendCapabilities, PixiBuildApiVersion,
     procedures::{
-        conda_build_v0::{CondaBuildParams, CondaBuildResult},
         conda_build_v1::{CondaBuildV1Params, CondaBuildV1Result},
-        conda_metadata::{CondaMetadataParams, CondaMetadataResult},
         conda_outputs::{CondaOutputsParams, CondaOutputsResult},
     },
 };
@@ -134,39 +132,6 @@ impl Backend {
         self.api_version
     }
 
-    pub async fn conda_get_metadata(
-        &self,
-        params: CondaMetadataParams,
-    ) -> Result<CondaMetadataResult, CommunicationError> {
-        assert!(
-            self.inner.capabilities().provides_conda_metadata(),
-            "This backend does not support the conda get metadata procedure"
-        );
-        match &self.inner {
-            BackendImplementation::JsonRpc(json_rpc) => json_rpc.conda_get_metadata(params).await,
-            BackendImplementation::InMemory(in_memory) => in_memory.conda_get_metadata(params),
-        }
-    }
-
-    pub async fn conda_build_v0<W: BackendOutputStream + Send + 'static>(
-        &self,
-        params: CondaBuildParams,
-        output_stream: W,
-    ) -> Result<CondaBuildResult, CommunicationError> {
-        assert!(
-            self.inner.capabilities().provides_conda_build_v0(),
-            "This backend does not support the conda build v0 procedure"
-        );
-        match &self.inner {
-            BackendImplementation::JsonRpc(json_rpc) => {
-                json_rpc.conda_build_v0(params, output_stream).await
-            }
-            BackendImplementation::InMemory(in_memory) => {
-                in_memory.conda_build_v0(params, &output_stream)
-            }
-        }
-    }
-
     pub async fn conda_build_v1<W: BackendOutputStream + Send + 'static>(
         &self,
         params: CondaBuildV1Params,
