@@ -2,9 +2,10 @@
 
 use std::path::PathBuf;
 
+use ordermap::OrderMap;
 use serde::{Deserialize, Serialize};
 
-use crate::VersionedProjectModel;
+use crate::{TargetSelectorV1, VersionedProjectModel};
 
 pub const METHOD_NAME: &str = "initialize";
 
@@ -36,6 +37,11 @@ pub struct InitializeParams {
     /// This is an absolute path.
     pub source_dir: Option<PathBuf>,
 
+    /// The root directory of the workspace.
+    ///
+    /// This is an absolute path.
+    pub workspace_root: Option<PathBuf>,
+
     /// Optionally the cache directory to use for any caching activity.
     pub cache_directory: Option<PathBuf>,
 
@@ -46,6 +52,9 @@ pub struct InitializeParams {
 
     /// Backend specific configuration passed from the frontend to the backend.
     pub configuration: Option<serde_json::Value>,
+
+    /// Targets that apply to the backend.
+    pub target_configuration: Option<OrderMap<TargetSelectorV1, serde_json::Value>>,
 }
 
 /// The result of the initialize request.
