@@ -90,6 +90,9 @@ pub struct SourceBuildSpec {
     /// The protocols that are enabled for this source
     #[serde(skip_serializing_if = "crate::is_default")]
     pub enabled_protocols: EnabledProtocols,
+
+    /// Force rebuild even if the build cache is up to date.
+    pub force: bool,
 }
 
 #[derive(Debug, Clone)]
@@ -127,33 +130,87 @@ impl SourceBuildSpec {
     ) -> Result<SourceBuildResult, CommandDispatcherError<SourceBuildError>> {
         // If the output directory is not set, we want to use the build cache. Read the
         // build cache in that case.
-        let (output_directory, build_cache) =
-            if let Some(output_directory) = self.output_directory.clone() {
-                (output_directory, None)
-            } else {
-                // Query the source build cache.
-                let build_cache = command_dispatcher
-                    .source_build_cache_status(SourceBuildCacheStatusSpec {
-                        package: self.package.clone(),
-                        build_environment: self.build_environment.clone(),
-                        source: self.source.clone(),
-                        channels: self.channels.clone(),
-                        channel_config: self.channel_config.clone(),
-                        enabled_protocols: self.enabled_protocols.clone(),
-                    })
-                    .await
-                    .map_err_with(SourceBuildError::from)?;
+        let (output_directory, build_cache) = if let Some(output_directory) =
+            self.output_directory.clone()
+        {
+            (output_directory, None)
+        } else {
+            // Query the source build cache.
+            let build_cache = command_dispatcher
+                .source_build_cache_status(SourceBuildCacheStatusSpec {
+                    package: self.package.clone(),
+                    build_environment: self.build_environment.clone(),
+                    source: self.source.clone(),
+                    channels: self.channels.clone(),
+                    channel_config: self.channel_config.clone(),
+                    enabled_protocols: self.enabled_protocols.clone(),
+                })
+                .await
+                .map_err_with(SourceBuildError::from)?;
 
-                if let CachedBuildStatus::UpToDate(cached_build) = &build_cache.cached_build {
+            // If the build is up to date and we are not forcing a rebuild, return the cached build.
+            // but if we force a rebuild, and we already have an new cached build, we can reuse the cache entry.
+            if let CachedBuildStatus::UpToDate(cached_build) =
+                &*build_cache.cached_build.lock().await
+            {
+                if !self.force {
                     // If the build is up to date, we can return the cached build.
+                    tracing::debug!(
+                        source = %self.source,
+                        package = ?cached_build.record.package_record.name,
+                        build = %cached_build.record.package_record.build,
+                        output = %cached_build.record.file_name,
+                        "using cached up-to-date source build",
+                    );
                     return Ok(SourceBuildResult {
                         output_file: build_cache.cache_dir.join(&cached_build.record.file_name),
                         record: cached_build.record.clone(),
                     });
                 }
+                tracing::debug!(
+                    "source build for {} is up to date, but force rebuild is set, rebuilding anyway",
+                    self.package.name.as_normalized()
+                );
+            }
+            if let CachedBuildStatus::New(cached_build) = &*build_cache.cached_build.lock().await {
+                tracing::debug!(
+                    "source build for {} is already built and marked as new, reusing the cache entry",
+                    self.package.name.as_normalized()
+                );
+                tracing::debug!(
+                    source = %self.source,
+                    package = ?cached_build.record.package_record.name,
+                    build = %cached_build.record.package_record.build,
+                    output = %cached_build.record.file_name,
+                    "using cached new source build",
+                );
+                // dont matter if we forceit , we can reuse the cache entry
+                return Ok(SourceBuildResult {
+                    output_file: build_cache.cache_dir.join(&cached_build.record.file_name),
+                    record: cached_build.record.clone(),
+                });
+            }
 
-                (build_cache.cache_dir.clone(), Some(build_cache))
-            };
+            match &*build_cache.cached_build.lock().await {
+                CachedBuildStatus::Stale(existing) => {
+                    tracing::debug!(
+                        source = %self.source,
+                        package = ?existing.record.package_record.name,
+                        build = %existing.record.package_record.build,
+                        "rebuilding stale source build",
+                    );
+                }
+                CachedBuildStatus::Missing => {
+                    tracing::debug!(
+                        source = %self.source,
+                        "no cached source build; starting fresh build",
+                    );
+                }
+                CachedBuildStatus::UpToDate(_) | CachedBuildStatus::New(_) => {}
+            }
+
+            (build_cache.cache_dir.clone(), Some(build_cache))
+        };
 
         // Check out the source code.
         let source_checkout = command_dispatcher
@@ -204,6 +261,12 @@ impl SourceBuildSpec {
                 .key(),
             ),
         };
+        tracing::debug!(
+            source = %self.source,
+            work_directory = %work_directory.display(),
+            backend = backend.identifier(),
+            "using work directory for source build",
+        );
 
         // Clean the working directory if requested.
         if self.clean {
@@ -215,6 +278,7 @@ impl SourceBuildSpec {
         }
 
         // Build the package using the v1 build method.
+        let source_for_logging = self.source.clone();
         let mut built_source = self
             .build_v1(
                 command_dispatcher,
@@ -292,18 +356,32 @@ impl SourceBuildSpec {
                 .expect("the output file should be a valid URL"),
             channel: None,
         };
+        tracing::debug!(
+            source = %source_for_logging,
+            package = ?record.package_record.name,
+            build = %record.package_record.build,
+            output = %record.file_name,
+            "built source package",
+        );
 
         // Update the cache entry if we have one.
         if let Some(build_cache) = build_cache {
             let mut entry = build_cache.entry.lock().await;
+            // set the status that its a new cache
+            // so on the next run we can distinguish between up to date ( was already saved from previous session)
+            // and new that was just build now
+            let cached_build = CachedBuild {
+                source: source_checkout
+                    .pinned
+                    .is_mutable()
+                    .then_some(built_source.metadata.clone()),
+                record: record.clone(),
+            };
+
+            let mut cached_entry = build_cache.cached_build.lock().await;
+            *cached_entry = CachedBuildStatus::New(cached_build.clone());
             entry
-                .insert(CachedBuild {
-                    source: source_checkout
-                        .pinned
-                        .is_mutable()
-                        .then_some(built_source.metadata),
-                    record: record.clone(),
-                })
+                .insert(cached_build)
                 .await
                 .map_err(SourceBuildError::BuildCache)
                 .map_err(CommandDispatcherError::Failed)?;
