@@ -31,7 +31,7 @@ use pixi_install_pypi::{
 use pixi_manifest::{ChannelPriority, EnvironmentName, FeaturesExt};
 use pixi_progress::global_multi_progress;
 use pixi_record::{ParseLockFileError, PixiRecord};
-use pixi_utils::prefix::Prefix;
+use pixi_utils::{prefix::Prefix, variants::VariantConfig};
 use pixi_uv_context::UvResolutionContext;
 use pixi_uv_conversions::{
     ConversionError, to_extra_name, to_marker_environment, to_normalize, to_uv_extra_name,
@@ -65,7 +65,9 @@ use crate::{
         virtual_packages::validate_system_meets_environment_requirements,
     },
     workspace::{
-        Environment, EnvironmentVars, HasWorkspaceRef, get_activated_environment_variables,
+        Environment, EnvironmentVars, HasWorkspaceRef,
+        errors::VariantsError,
+        get_activated_environment_variables,
         grouped_environment::{GroupedEnvironment, GroupedEnvironmentName},
     },
 };
@@ -234,6 +236,10 @@ pub enum SolveCondaEnvironmentError {
 
     #[error(transparent)]
     ParseChannels(#[from] ParseChannelError),
+
+    #[error(transparent)]
+    #[diagnostic(transparent)]
+    Variants(#[from] VariantsError),
 }
 
 /// Options to pass to [`Workspace::update_lock_file`].
@@ -1949,7 +1955,10 @@ async fn spawn_solve_conda_environment_task(
         .collect::<Result<Vec<_>, _>>()?;
 
     // Determine the build variants
-    let variants = group.workspace().variants(platform);
+    let VariantConfig {
+        variants,
+        variant_files,
+    } = group.workspace().variants(platform)?;
 
     let start = Instant::now();
 
@@ -1967,6 +1976,7 @@ async fn spawn_solve_conda_environment_task(
             exclude_newer,
             channel_config,
             variants: Some(variants),
+            variant_files: Some(variant_files),
             enabled_protocols: Default::default(),
         })
         .await
