@@ -7,10 +7,10 @@ use url::Url;
 #[derive(Debug, Clone)]
 pub struct Package {
     /// The name of the project
-    pub name: String,
+    pub name: Option<String>,
 
     /// The version of the project
-    pub version: Version,
+    pub version: Option<Version>,
 
     /// An optional project description
     pub description: Option<String>,
@@ -39,7 +39,7 @@ pub struct Package {
 
 impl Package {
     /// Creates a new package with the given name and version.
-    pub fn new(name: String, version: Version) -> Self {
+    pub fn new(name: Option<String>, version: Option<Version>) -> Self {
         Self {
             name,
             version,
