@@ -339,6 +339,18 @@ impl PixiSpec {
         !self.is_binary()
     }
 
+    /// Returns true if this spec represents a mutable source.
+    /// A spec is mutable if it points to a local path-based source (non-binary).
+    pub fn is_mutable(&self) -> bool {
+        match self {
+            Self::Version(_) => false,
+            Self::DetailedVersion(_) => false,
+            Self::Url(_) => false,
+            Self::Git(_) => false,
+            Self::Path(path) => !path.is_binary(),
+        }
+    }
+
     /// Converts this instance into a [`toml_edit::Value`].
     pub fn to_toml_value(&self) -> toml_edit::Value {
         ::serde::Serialize::serialize(self, toml_edit::ser::ValueSerializer::new())
