@@ -1,11 +1,6 @@
-// use uv_normalize::PackageName;
-// use pep508_rs::PackageName;
-
 use std::error::Error;
 use std::fmt::{Debug, Display};
-use std::path::PathBuf;
 use thiserror::Error;
-use uv_distribution_filename::ExtensionError;
 use uv_pep440::VersionSpecifierBuildError;
 
 #[derive(Debug)]
@@ -144,7 +139,4 @@ pub enum ConversionError {
 
     #[error(transparent)]
     FmtError(#[from] std::fmt::Error),
-
-    #[error("expected an archive but found path")]
-    ExpectedArchiveButFoundPath(PathBuf, #[source] ExtensionError),
 }
